@@ -3,37 +3,37 @@ BEGIN {
   $NetPacket::ARP::AUTHORITY = 'cpan:YANICK';
 }
 # ABSTRACT: Assemble and disassemble ARP (Address Resolution Protocol) packets.
-$NetPacket::ARP::VERSION = '1.5.0';
+$NetPacket::ARP::VERSION = '1.6.0';
 use strict;
-use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
+use warnings;
 
+use parent 'NetPacket';
 
-BEGIN {
-    @ISA = qw(Exporter NetPacket);
-
-# Items to export into callers namespace by default
-# (move infrequently used names to @EXPORT_OK below)
-
-    @EXPORT = qw(
-    );
+our @EXPORT = qw();
 
 # Other items we are prepared to export if requested
 
-    @EXPORT_OK = qw(arp_strip
-		    ARP_OPCODE_REQUEST ARP_OPCODE_REPLY RARP_OPCODE_REQUEST 
-		    RARP_OPCODE_REPLY
+our @EXPORT_OK = qw(
+    arp_strip
+    ARP_OPCODE_REQUEST ARP_OPCODE_REPLY RARP_OPCODE_REQUEST 
+    RARP_OPCODE_REPLY
+		    ARPHRD_NETROM ARPHRD_ETHER ARPHRD_EETHER ARPHRD_AX25
+		    ARPHRD_PRONET ARPHRD_CHAOS ARPHRD_IEEE802 ARPHRD_ARCNET
+		    ARPHRD_APPLETLK ARPHRD_DLCI ARPHRD_ATM ARPHRD_METRICOM
+		    ARPHRD_IEEE1394 ARPHRD_EUI64 ARPHRD_INFINIBAND
     );
 
-# Tags:
-
-    %EXPORT_TAGS = (
+our  %EXPORT_TAGS = (
     ALL         => [@EXPORT, @EXPORT_OK],
     opcodes     => [qw(ARP_OPCODE_REQUEST ARP_OPCODE_REPLY RARP_OPCODE_REQUEST 
 		       RARP_OPCODE_REPLY)],
+    protos      => [qw(ARPHRD_NETROM ARPHRD_ETHER ARPHRD_AX25 ARPHRD_PRONET
+		       ARPHRD_CHAOS ARPHRD_IEEE802 ARPHRD_ARCNET
+		       ARPHRD_APPLETLK ARPHRD_DLCI ARPHRD_ATM ARPHRD_METRICOM
+		       ARPHRD_IEEE1394 ARPHRD_EUI64 ARPHRD_INFINIBAND)],
     strip       => [qw(arp_strip)],
 );
 
-}
 
 # 
 # List of opcode values
@@ -44,6 +44,26 @@ use constant ARP_OPCODE_REPLY    => 2;
 use constant RARP_OPCODE_REQUEST => 3;
 use constant RARP_OPCODE_REPLY   => 4;
 
+#
+# List of hardware identifiers
+#
+
+use constant ARPHRD_NETROM	=> 0;
+use constant ARPHRD_ETHER	=> 1;
+use constant ARPHRD_EETHER	=> 2;
+use constant ARPHRD_AX25	=> 3;
+use constant ARPHRD_PRONET	=> 4;
+use constant ARPHRD_CHAOS	=> 5;
+use constant ARPHRD_IEEE802	=> 6;
+use constant ARPHRD_ARCNET	=> 7;
+use constant ARPHRD_APPLETLK	=> 8;
+use constant ARPHRD_DLCI	=> 15;
+use constant ARPHRD_ATM		=> 19;
+use constant ARPHRD_METRICOM	=> 23;
+use constant ARPHRD_IEEE1394	=> 24;
+use constant ARPHRD_EUI64	=> 27;
+use constant ARPHRD_INFINIBAND	=> 32;
+
 #
 # Decode the packet
 #
@@ -109,7 +129,7 @@ NetPacket::ARP - Assemble and disassemble ARP (Address Resolution Protocol) pack
 
 =head1 VERSION
 
-version 1.5.0
+version 1.6.0
 
 =head1 SYNOPSIS
 
