@@ -1,20 +1,13 @@
-#
-# NetPacket::TCP - Decode and encode TCP (Transmission Control
-# Protocol) packets. 
-#
-# Encode and checksumming part, Stephanie Wehner, atrak@itsx.com
-
 package NetPacket::TCP;
 BEGIN {
   $NetPacket::TCP::AUTHORITY = 'cpan:YANICK';
 }
 # ABSTRACT: Assemble and disassemble TCP (Transmission Control Protocol) packets.
-$NetPacket::TCP::VERSION = '1.5.0';
+$NetPacket::TCP::VERSION = '1.6.0';
 use strict;
-use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
-use NetPacket;
+use warnings;
 
-my $myclass;
+use parent 'NetPacket';
 
 # TCP Flags
 
@@ -27,29 +20,15 @@ use constant URG => 0x20;
 use constant ECE => 0x40;
 use constant CWR => 0x80;
 
-BEGIN {
-    @ISA = qw(Exporter NetPacket);
+our @EXPORT = qw(FIN SYN RST PSH ACK URG ECE CWR);
 
-# Items to export into callers namespace by default
-# (move infrequently used names to @EXPORT_OK below)
+our @EXPORT_OK = qw(tcp_strip );
 
-    @EXPORT = qw(FIN SYN RST PSH ACK URG ECE CWR
-    );
-
-# Other items we are prepared to export if requested
-
-    @EXPORT_OK = qw(tcp_strip 
-    );
-
-# Tags:
-
-    %EXPORT_TAGS = (
+our %EXPORT_TAGS = (
     ALL         => [@EXPORT, @EXPORT_OK],
     strip       => [qw(tcp_strip)],  
 );
 
-}
-
 #
 # Strip header from packet and return the data contained in it
 #
@@ -299,7 +278,7 @@ NetPacket::TCP - Assemble and disassemble TCP (Transmission Control Protocol) pa
 
 =head1 VERSION
 
-version 1.5.0
+version 1.6.0
 
 =head1 SYNOPSIS
 
