@@ -3,27 +3,24 @@ BEGIN {
   $NetPacket::USBMon::AUTHORITY = 'cpan:YANICK';
 }
 #ABSTRACT: Assemble and disassemble USB packets captured via Linux USBMon interface.
-$NetPacket::USBMon::VERSION = '1.5.0';
+$NetPacket::USBMon::VERSION = '1.6.0';
 use 5.10.0;
-
 use strict;
-use vars qw(@ISA @EXPORT_OK %EXPORT_TAGS);
-use NetPacket;
+use warnings;
 
-BEGIN {
-    @ISA = qw(Exporter NetPacket);
+use parent 'NetPacket';
 
-    @EXPORT_OK = qw(
-                    USB_TYPE_SUBMISSION USB_TYPE_CALLBACK USB_TYPE_ERROR
-                    USB_XFER_TYPE_ISO USB_XFER_TYPE_INTR
-                    USB_XFER_TYPE_CONTROL USB_XFER_TYPE_BULK
-                    USB_FLAG_SETUP_IRRELEVANT USB_FLAG_SETUP_RELEVANT
-                    USB_FLAG_DATA_ERROR USB_FLAG_DATA_INCOMING
-                    USB_FLAG_DATA_OUTGOING USB_FLAG_DATA_PRESENT
-                    USB_TYPE_VENDOR
-    );
+our @EXPORT_OK = qw(
+    USB_TYPE_SUBMISSION USB_TYPE_CALLBACK USB_TYPE_ERROR
+    USB_XFER_TYPE_ISO USB_XFER_TYPE_INTR
+    USB_XFER_TYPE_CONTROL USB_XFER_TYPE_BULK
+    USB_FLAG_SETUP_IRRELEVANT USB_FLAG_SETUP_RELEVANT
+    USB_FLAG_DATA_ERROR USB_FLAG_DATA_INCOMING
+    USB_FLAG_DATA_OUTGOING USB_FLAG_DATA_PRESENT
+    USB_TYPE_VENDOR
+);
 
-    %EXPORT_TAGS =(
+our %EXPORT_TAGS =(
     ALL         => \@EXPORT_OK,
     types       => [qw(USB_TYPE_SUBMISSION USB_TYPE_CALLBACK
                        USB_TYPE_ERROR)],
@@ -35,7 +32,6 @@ BEGIN {
     setup_types => [qw(USB_TYPE_VENDOR)],
 );
 
-}
 
 use constant USB_TYPE_SUBMISSION        => 'S';
 use constant USB_TYPE_CALLBACK          => 'C';
@@ -151,7 +147,7 @@ NetPacket::USBMon - Assemble and disassemble USB packets captured via Linux USBM
 
 =head1 VERSION
 
-version 1.5.0
+version 1.6.0
 
 =head1 SYNOPSIS
 
